import { ServiceLogger } from "@/services/logging";
import { TimeSpan } from "@/services/timespan";
export declare class AdaptivePoller {
    private readonly initialDelay;
    private readonly logger;
    private readonly maxDelay;
    private readonly factor;
    private readonly resetPeriod;
    private readonly linearStep;
    private currentTimeout;
    private currentDelay;
    private lastErrorTime;
    private polling;
    private operation;
    private onError;
    private onFail;
    get isPolling(): boolean;
    /**
     * @param logger of the service that uses this polling
     * @param initialDelay initial interval between operations (in ms)
     * @param maxDelay maximum interval on errors (in ms)
     * @param factor multiplier for exponential interval increase
     * @param resetPeriod period (in ms) during which if no errors occur, the interval starts to decrease linearly
     * @param linearStep amount (in ms) by which the interval decreases after a successful operation, if resetPeriod has passed
     */
    constructor(initialDelay?: TimeSpan, logger?: ServiceLogger | null, maxDelay?: TimeSpan, factor?: number, resetPeriod?: TimeSpan, linearStep?: TimeSpan);
    start(operation: () => Promise<void>, onError?: ((error: Error) => void) | null, onFail?: ((error: Error) => void) | null): void;
    stop(): void;
    private runPoll;
    private scheduleNextPoll;
}
