"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExponentialBackoff = void 0;
const tasks_1 = require("./tasks");
class ExponentialBackoff {
    options;
    constructor(options) {
        this.options = options;
    }
    execute(operation) {
        return new Promise(async (resolve, reject) => {
            let lastError = null;
            let currentDelay = this.options.initialDelay;
            while (currentDelay <= this.options.maxDelay) {
                try {
                    const result = await this.attempt(operation);
                    resolve(result);
                    return;
                }
                catch (error) {
                    lastError = error;
                    await (0, tasks_1.Wait)(currentDelay);
                    currentDelay = this.getUpdatedDelay(currentDelay);
                }
            }
            reject(lastError);
        });
    }
    attempt(operation) {
        return new Promise(async (resolve, reject) => {
            try {
                const result = await operation();
                resolve(result);
            }
            catch (error) {
                reject(error);
            }
        });
    }
    getUpdatedDelay(currentDelay) {
        const jitter = this.options.jitter ? Math.random() * this.options.jitter.totalMilliseconds : 0;
        const newDelay = (currentDelay.totalMilliseconds * this.options.factor) + jitter;
        return TimeSpan.fromMilliseconds(newDelay);
    }
}
exports.ExponentialBackoff = ExponentialBackoff;
