"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RestRequest = void 0;
const axios_1 = __importDefault(require("axios"));
const backoff_1 = require("../../services/backoff");
const timespan_1 = require("@/services/timespan");
class RestRequest {
    throwException;
    backoff;
    constructor(throwException = false, backoffOption) {
        this.throwException = throwException;
        if (!backoffOption)
            backoffOption = {
                initialDelay: timespan_1.TimeSpan.fromSeconds(5),
                maxDelay: timespan_1.TimeSpan.fromSeconds(30),
                factor: 2
            };
        this.backoff = new backoff_1.ExponentialBackoff(backoffOption);
    }
    get(url, config) {
        return new Promise((resolve, reject) => {
            this.backoff.execute(() => axios_1.default.get(url, config))
                .then((response) => {
                resolve(response);
            })
                .catch((error) => {
                reject(error);
                if (this.throwException)
                    throw error;
            });
        });
    }
    post(url, data, config) {
        return new Promise((resolve, reject) => {
            this.backoff.execute(() => axios_1.default.post(url, data, config))
                .then((response) => {
                resolve(response);
            })
                .catch((error) => {
                reject(error);
                if (this.throwException)
                    throw error;
            });
        });
    }
}
exports.RestRequest = RestRequest;
